@@ -75,8 +75,8 @@ class ReconPlot(Plot):
         #Set default properties
         default_prop={'cmap':'category','levels':(np.nanmin(recon_data[varname]),np.nanmax(recon_data[varname])),\
                       'sortby':varname,'ascending':(varname!='p_sfc'),'linewidth':1.5,'ms':7.5,'marker':'o','zorder':None}
-        default_map_prop={'res':'m','land_color':'#FBF5EA','ocean_color':'#EDFBFF',\
-                          'linewidth':0.5,'linecolor':'k','figsize':(14,9),'dpi':200}
+        default_map_prop={'res':'m','land_color':'#FBF5EA','ocean_color':'#EDFBFF','linewidth':0.5,'linecolor':'k',
+                          'figsize':(14,9),'dpi':200,'plot_gridlines':True}
         
         #Initialize plot
         prop = self.add_prop(prop,default_prop)
@@ -184,7 +184,8 @@ class ReconPlot(Plot):
             bound_w,bound_e,bound_s,bound_n = self.set_projection(domain)
         
         #Determine number of lat/lon lines to use for parallels & meridians
-        self.plot_lat_lon_lines([bound_w,bound_e,bound_s,bound_n])
+        if map_prop['plot_gridlines']:
+            self.plot_lat_lon_lines([bound_w,bound_e,bound_s,bound_n])
         
         #--------------------------------------------------------------------------------------
         
@@ -289,7 +290,7 @@ class ReconPlot(Plot):
 
         #Set default properties
         default_prop={'cmap':'category','levels':None,'left_title':'','right_title':'All storms','pcolor':True}
-        default_map_prop={'res':'m','land_color':'#FBF5EA','ocean_color':'#EDFBFF','linewidth':0.5,'linecolor':'k','figsize':(14,9),'dpi':200}
+        default_map_prop={'res':'m','land_color':'#FBF5EA','ocean_color':'#EDFBFF','linewidth':0.5,'linecolor':'k','figsize':(14,9),'dpi':200,'plot_gridlines':True}
                           
         #Initialize plot
         prop = self.add_prop(prop,default_prop)
@@ -383,7 +384,8 @@ class ReconPlot(Plot):
             bound_w,bound_e,bound_s,bound_n = self.set_projection(domain)
         
         #Determine number of lat/lon lines to use for parallels & meridians
-        self.plot_lat_lon_lines([bound_w,bound_e,bound_s,bound_n])
+        if map_prop['plot_gridlines']:
+            self.plot_lat_lon_lines([bound_w,bound_e,bound_s,bound_n])
 
         #--------------------------------------------------------------------------------------
                 
@@ -546,7 +548,7 @@ class ReconPlot(Plot):
 
         #Set default properties
         default_prop={'cmap':'category','levels':None,'left_title':'','right_title':'','pcolor':True}
-        default_map_prop={'res':'m','land_color':'#FBF5EA','ocean_color':'#EDFBFF','linewidth':0.5,'linecolor':'k','figsize':(12.5,8.5),'dpi':120}
+        default_map_prop={'res':'m','land_color':'#FBF5EA','ocean_color':'#EDFBFF','linewidth':0.5,'linecolor':'k','figsize':(12.5,8.5),'dpi':120,'plot_gridlines':True}
         
         #Initialize plot
         prop = self.add_prop(prop,default_prop)
@@ -600,7 +602,8 @@ class ReconPlot(Plot):
             bound_w,bound_e,bound_s,bound_n = self.set_projection(domain)
 
         #Determine number of lat/lon lines to use for parallels & meridians
-        self.plot_lat_lon_lines([bound_w,bound_e,bound_s,bound_n])
+        if map_prop['plot_gridlines']:
+            self.plot_lat_lon_lines([bound_w,bound_e,bound_s,bound_n])
         
 #        rightarrow = u"\u2192"
 #        plt.xlabel(f'W {rightarrow} E Distance (km)')
